@@ -14,6 +14,8 @@ Usage::
 import sys
 from typing import Dict, Sequence
 
+from typing_extensions import NotRequired
+
 if sys.version_info >= (3, 9):
     from typing import TypedDict
 else:
@@ -30,32 +32,19 @@ __all__ = (
     "StartDeviceAuthorizationResponseTypeDef",
 )
 
-_RequiredCreateTokenRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateTokenRequestRequestTypeDef",
+CreateTokenRequestRequestTypeDef = TypedDict(
+    "CreateTokenRequestRequestTypeDef",
     {
         "clientId": str,
         "clientSecret": str,
         "grantType": str,
         "deviceCode": str,
+        "code": NotRequired[str],
+        "refreshToken": NotRequired[str],
+        "scope": NotRequired[Sequence[str]],
+        "redirectUri": NotRequired[str],
     },
 )
-_OptionalCreateTokenRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateTokenRequestRequestTypeDef",
-    {
-        "code": str,
-        "refreshToken": str,
-        "scope": Sequence[str],
-        "redirectUri": str,
-    },
-    total=False,
-)
-
-
-class CreateTokenRequestRequestTypeDef(
-    _RequiredCreateTokenRequestRequestTypeDef, _OptionalCreateTokenRequestRequestTypeDef
-):
-    pass
-
 
 CreateTokenResponseTypeDef = TypedDict(
     "CreateTokenResponseTypeDef",
@@ -69,27 +58,14 @@ CreateTokenResponseTypeDef = TypedDict(
     },
 )
 
-_RequiredRegisterClientRequestRequestTypeDef = TypedDict(
-    "_RequiredRegisterClientRequestRequestTypeDef",
+RegisterClientRequestRequestTypeDef = TypedDict(
+    "RegisterClientRequestRequestTypeDef",
     {
         "clientName": str,
         "clientType": str,
+        "scopes": NotRequired[Sequence[str]],
     },
 )
-_OptionalRegisterClientRequestRequestTypeDef = TypedDict(
-    "_OptionalRegisterClientRequestRequestTypeDef",
-    {
-        "scopes": Sequence[str],
-    },
-    total=False,
-)
-
-
-class RegisterClientRequestRequestTypeDef(
-    _RequiredRegisterClientRequestRequestTypeDef, _OptionalRegisterClientRequestRequestTypeDef
-):
-    pass
-
 
 RegisterClientResponseTypeDef = TypedDict(
     "RegisterClientResponseTypeDef",
